migrate

package
v0.9.0-test.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 28, 2023 License: Apache-2.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Migrate

func Migrate(ctx context.Context, log logr.Logger, c client.Client) error

Migrate contains logic which should run once during controller start. The main use case for this handler is network-operator upgrade for example, the handler can contain logic to change old data format to a new one or to remove unneeded resources from the cluster

Types

This section is empty.

Jump to